@@ -50,4 +50,4 @@ class QuotaTemplate(NetBoxModel):
         return str(f"{self.template_name}")
 
     def get_absolute_url(self):
-        return reverse('plugins:netbox_manage_project:quotatemplate', args=[self.pk])
+        return reverse('plugins:netbox_project_quota:quotatemplate', args=[self.pk])
